pub struct ComponentBuildConfigV1 {
pub command: Commands,
pub workdir: Option<String>,
pub watch: Vec<String>,
}Expand description
Component build configuration
Fields
command: CommandsThe command or commands to build the component. If multiple commands are specified, they are run sequentially from left to right.
Example: command = "cargo build --release", command = ["npm install", "npm run build"]
Learn more: https://spinframework.dev/build#setting-up-for-spin-build
workdir: Option<String>The working directory for the build command. If omitted, the build working
directory is the directory containing spin.toml.
Example: `workdir = “components/main”
Learn more: https://spinframework.dev/build#overriding-the-working-directory
watch: Vec<String>Source files to use in spin watch. This is a set of paths or glob patterns (relative
to the build working directory). A change to any matching file causes
spin watch to rebuild the application before restarting the application.
Example: watch = ["src/**/*.rs"]
Learn more: https://spinframework.dev/running-apps#monitoring-applications-for-changes
Implementations
Sourceimpl ComponentBuildConfig
impl ComponentBuildConfig
Sourcepub fn commands(&self) -> impl ExactSizeIterator<Item = &String>
pub fn commands(&self) -> impl ExactSizeIterator<Item = &String>
The commands to execute for the build